==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXTwoFactorManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTwoFactorManager::printSavedUserList{package NXTwoFactorManager;no 
warnings;NXMsg::send_response (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x73\x4b\x65\x79\x73\x4c\x69\x73\x74"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72");
main::nxrequire (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42");(my (
@publicKeys)=NXTwoFactorLoginDB::getAllPublicKeys ());(my (@labels)=(
"\x55\x73\x65\x72","\x4b\x65\x79"));(my (%keys)=());for ((my $i=
(0x1298+ 2980-0x1e3c));($i<@publicKeys);($i=($i+(0x01d0+ 2228-0x0a82)))){(my (
%key)=());($key{"\x55\x73\x65\x72"}=$publicKeys[$i]);($key{"\x4b\x65\x79"}=
$publicKeys[$i+(0x0e31+ 916-0x11c4)]);($keys{$i}=(\%key));}return (
NXTools::printTable ((\@labels),(\%keys)));}sub 
NXTwoFactorManager::removeUserKeys{package NXTwoFactorManager;no warnings;(my $user
=shift (@_));main::nxrequire (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42");(my (
@keys)=NXTwoFactorLoginDB::getAllPublicKeys ($user));if ((scalar (@keys)==
(0x0c4f+ 4831-0x1f2e))){NXMsg::error (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x4e\x6f\x74\x45\x78\x69\x73\x74\x73"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);return;}if ((NXTwoFactorLoginDB::removeUserKeys ($user)>
(0x141f+ 3713-0x22a0))){NXMsg::send_response (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x64"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);return;}NXMsg::error (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x45\x72\x72\x6f\x72"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);}package NXTwoFactorManager;no warnings;NXMsg::register_response (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x73\x4b\x65\x79\x73\x4c\x69\x73\x74"
,$GLOBAL::MSG_2FA_SAVED_KEYS_LIST);NXMsg::register_response (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x64"
,$GLOBAL::MSG_2FA_SAVED_KEYS_DEL);NXMsg::register_error (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x4e\x6f\x74\x45\x78\x69\x73\x74\x73"
,(0x0894+ 3246-0x134e));NXMsg::register_error (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x45\x72\x72\x6f\x72"
,(0x0860+ 6919-0x2173));return ((0x0469+ 7377-0x2139));

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXTwoFactorManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTwoFactorManager::printSavedUserList{package NXTwoFactorManager;no 
warnings;NXMsg::send_response (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x73\x4b\x65\x79\x73\x4c\x69\x73\x74"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72");
main::nxrequire (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42");(my (
@publicKeys)=NXTwoFactorLoginDB::getAllPublicKeys ());(my (@labels)=(
"\x55\x73\x65\x72","\x4b\x65\x79"));(my (%keys)=());for ((my $i=
(0x11df+ 237-0x12cc));($i<@publicKeys);($i=($i+(0x0509+ 4845-0x17f4)))){(my (
%key)=());($key{"\x55\x73\x65\x72"}=$publicKeys[$i]);($key{"\x4b\x65\x79"}=
$publicKeys[$i+(0x0383+ 5095-0x1769)]);($keys{$i}=(\%key));}return (
NXTools::printTable ((\@labels),(\%keys)));}sub 
NXTwoFactorManager::removeUserKeys{package NXTwoFactorManager;no warnings;(my $user
=shift (@_));main::nxrequire (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42");(my (
@keys)=NXTwoFactorLoginDB::getAllPublicKeys ($user));if ((scalar (@keys)==
(0x12e6+ 3939-0x2249))){NXMsg::error (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x4e\x6f\x74\x45\x78\x69\x73\x74\x73"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);return;}if ((NXTwoFactorLoginDB::removeUserKeys ($user)>
(0x1fdf+ 1114-0x2439))){NXMsg::send_response (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x64"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);return;}NXMsg::error (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x45\x72\x72\x6f\x72"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);}package NXTwoFactorManager;no warnings;NXMsg::register_response (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x73\x4b\x65\x79\x73\x4c\x69\x73\x74"
,$GLOBAL::MSG_2FA_SAVED_KEYS_LIST);NXMsg::register_response (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x64"
,$GLOBAL::MSG_2FA_SAVED_KEYS_DEL);NXMsg::register_error (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x4e\x6f\x74\x45\x78\x69\x73\x74\x73"
,(0x1bd7+ 1664-0x2063));NXMsg::register_error (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x45\x72\x72\x6f\x72"
,(0x13c6+ 2822-0x1cd8));return ((0x03ff+ 8186-0x23f8));
